==> EntitySyncer-0.0.9-sources.jar: org/openzen/entitysyncer/SimpleLocale.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.openzen.entitysyncer;

/**
 *
 * @author Hoofdgebruiker
 */
public enum SimpleLocale {
	GENERIC(""),
	AFAR("af"),
	AFAR_DJIBOUTI("af", "dj", AFAR),
	AFAR_ERITREA("af", "er", AFAR),
	AFAR_ETHIOPIA("af", "et", AFAR),
	AFRIKAANS("af"),
	ALBANIAN("sq"),
	AMHARIC("am"), // Ethiopia
	ARAGONESE("an"), // Spain
	ARABIC("ar"),
	ARABIC_ALGERIA("ar", "dz", ARABIC),
	ARABIC_BAHRAIN("ar", "bh", ARABIC),
	ARABIC_EGYPT("ar", "eg", ARABIC),
	ARABIC_INDIA("ar", "in", ARABIC),
	ARABIC_IRAQ("ar", "iq", ARABIC),
	ARABIC_JORDAN("ar", "jo", ARABIC),
	ARABIC_KUWAIT("ar", "kw", ARABIC),
	ARABIC_LEBANON("ar", "lb", ARABIC),
	ARABIC_LIBYA("ar", "ly", ARABIC),
	ARABIC_MOROCCO("ar", "ma", ARABIC),
	ARABIC_OMAN("ar", "om", ARABIC),
	ARABIC_QATAR("ar", "qa", ARABIC),
	ARABIC_SAUDI_ARABIA("ar", "sa", ARABIC),
	ARABIC_SUDAN("ar", "sd", ARABIC),
	ARABIC_SYRIA("ar", "sy", ARABIC),
	ARABIC_TUNISIA("ar", "tn", ARABIC),
	ARABIC_EMIRATES("ar", "ae", ARABIC),
	ARABIC_YEMEN("ar", "ye", ARABIC),
	ARMENIAN("hy"),
	ASSAMESE("as"), // India
	ASTURIAN("ast"), // Spain
	AZERI("az"), // Azerbaijan
	AZERI_CYRILLIC("az", "az", AZERI),
	AZERI_LATIN("az", "az", AZERI),
	BASQUE("eu"),
	BELARUSIAN("be"),
	BENGALI("bn"),
	BENGALI_BANGLADESH("bn", "bn", BENGALI),
	BENGALI_INDIA("bn", "bn", BENGALI),
	BERBER("ber"),
	BERBER_ALGERIA("ber", "dz", BERBER),
	BERBER_MOROCCO("ber", "ma", BERBER),
	BHUTANI("dz"),
	BILIN("byn"), // Eritrea
	BOSNIAN("bs"),
	BRETON("br"),
	BULGARIAN("bg"),
	BURMESE("my"),
	CATALAN("ca"),
	CATALAN_ANDORRA("ca", "ad", CATALAN),
	CATALAN_SPAIN("ca", "es", CATALAN),
	CATALAN_FRANCE("ca", "fr", CATALAN),
	CATALAN_ITALIAN("ca", "it", CATALAN),
	CHINESE("zh"),
	CHINESE_CHINA("zh", "cn", CHINESE),
	CHINESE_HONGKONG("zh", "hk", CHINESE),
	CHINESE_MACAU("zh", "mo", CHINESE),
	CHINESE_SINGAPORE("zh", "sg", CHINESE),
	CHINESE_TAIWAN("zh", "tw", CHINESE),
	CRIMEAN_TARTAR("crh"), // Ukraine
	CROATIAN("hr"),
	CZECH("cs"),
	DANISH("da"),
	DIVEHI("dv"), // Maldives
	DUTCH("nl"),
	DUTCH_BELGIUM("nl", "be", DUTCH),
	DUTCH_NETHERLANDS("nl", "nl", DUTCH),
	EDO(""),
	ENGLISH("en"),
	ENGLISH_ANTIGUA_BARBUA("en", "ag", ENGLISH),
	ENGLISH_AUSTRALIA("en", "au", ENGLISH),
	ENGLISH_BELIZE("en", "bz", ENGLISH),
	ENGLISH_BOTSWANA("en", "bw", ENGLISH),
	ENGLISH_CANADA("en", "ca", ENGLISH),
	ENGLISH_CARIBBEAN("en", "cb", ENGLISH),
	ENGLISH_DENMARK("en", "dk", ENGLISH),
	ENGLISH_GREAT_BRITAIN("en", "gb", ENGLISH),
	ENGLISH_HONGKONG("en", "hk", ENGLISH),
	ENGLISH_INDIA("en", "in", ENGLISH),
	ENGLISH_IRELAND("en", "ie", ENGLISH),
	ENGLISH_JAMAICA("en", "jm", ENGLISH),
	ENGLISH_NEW_ZEALAND("en", "nz", ENGLISH),
	ENGLISH_NIGERIA("en", "ng", ENGLISH),
	ENGLISH_PHILLIPPINES("en", "ph", ENGLISH),
	ENGLISH_SINGAPORE("en", "sg", ENGLISH),
	ENGLISH_SOUTH_AFRICA("en", "za", ENGLISH),
	ENGLISH_TRINIDAD("en", "tt", ENGLISH),
	ENGLISH_UNITED_STATES("en", "us", ENGLISH),
	ENGLISH_ZIMBABWE("en", "", ENGLISH),
	ESPERANTO("eo"),
	ESTONIAN("et"),
	FYRO("mk"), // Macedonia
	FAROESE("fo"),
	FARSI("fa"), // Persian
	FINNISH("fi"),
	FRENCH("fr"),
	FRENCH_BELGIUM("fr", "be", FRENCH),
	FRENCH_CAMEROON("fr", "", FRENCH),
	FRENCH_CANADA("fr", "ca", FRENCH),
	FRENCH_CONGO("fr", "", FRENCH),
	FRENCH_COTE_DIVOIRE("fr", "", FRENCH),
	FRENCH_FRANCE("fr", "fr", FRENCH),
	FRENCH_LUXEMBURG("fr", "lu", FRENCH),
	FRENCH_MALI("fr", "", FRENCH),
	FRENCH_MONACO("fr", "", FRENCH),
	FRENCH_MOROCCO("fr", "", FRENCH),
	FRENCH_SENEGAL("fr", "", FRENCH),
	FRENCH_SWITZERLAND("fr", "ch", FRENCH),
	FRENCH_WEST_INDIES("fr", "", FRENCH),
	FRISIAN(""), // Netherlands
	GAELIC("gd"),
	GAELIC_IRELAND("gd", "ie", GAELIC),
	GAELIC_SCOTLAND("gd", "", GAELIC),
	GALICIAN("gl"),
	GEORGIAN("ka"),
	GERMAN("de"),
	GERMAN_AUSTRIA("de", "at", GERMAN),
	GERMAN_BELGIUM("de", "be", GERMAN),
	GERMAN_GERMANY("de", "de", GERMAN),
	GERMAN_LIECHTENSTEIN("de", "li", GERMAN),
	GERMAN_LUXEMBOURG("de", "lu", GERMAN),
	GERMAN_SWITZERLAND("de", "ch", GERMAN),
	GREEK("el"),
	GREEK_CYPRUS("el", "cy", GREEK),
	GREEK_GREECE("el", "gr", GREEK),
	GUARANI("gn"), // Paraguay
	GUJARITI("gu"),
	HEBREW("he"),
	HINDI("hi"),
	HUNGARIAN("hu"),
	ICELANDIC("is"),
	IGBO(""), // Nigeria
	INDONESIAN("id"),
	ITALIAN("it"),
	ITALIAN_ITALY("it", "it", ITALIAN),
	ITALIAN_SWITZERLAND("it", "ch", ITALIAN),
	JAPANESE("ja"),
	KANNADA("kn"),
	KASHMIRI("ks"),
	KASHUBIAN("csb"), // Poland
	KAZAKH("kk"),
	KHMER("km"),
	KONKANI(""),
	KOREAN("ko"),
	KYRGYZ(""),
	LAO("lo"),
	LATIN("la"),
	LATVIAN("lv"),
	LITHUANIAN("lt"),
	MALAY("ms"),
	MALAY_BRUNEI("ms", "bn", MALAY),
	MALAY_MALAYSIA("ms", "my", MALAY),
	MALAYALAM("ml"),
	MALTESE("mt"),
	MANIPURI(""),
	MAORI("mi"),
	MARATHI("mr"),
	MONGOLIAN("mn"),
	NEPALI("ne"),
	NORWEGIAN("no"),
	NORWEGIAN_BOKML("no", "nb", NORWEGIAN),
	NORWEGIAN_NYNORSK("no", "nn", NORWEGIAN),
	ORIYA("or"),
	POLISH("pl"),
	PORTUGUESE("pt"),
	PORTUGUESE_BRAZIL("pt", "br", PORTUGUESE),
	PORTUGUESE_PORTUGAL("pt", "pt", PORTUGUESE),
	PUNJABI("pa"),
	RAETO("rm"),
	ROMANIAN("ro"),
	ROMANIAN_MOLDOVA("ro", "mo", ROMANIAN),
	ROMANIAN_ROMANIA("ro", "ro", ROMANIAN),
	RUSSIAN("ru"),
	RUSSIAN_RUSSIA("ru", "ru", RUSSIAN),
	RUSSIAN_MOLDOVA("ru", "mo", RUSSIAN),
	SAMI_LAPPISH(""),
	SANSKRIT("sa"),
	SERBIAN("sr"),
	SERBIAN_CYRILLIC("sr", "sp", SERBIAN),
	SERBIAN_LATIN("sr", "sp", SERBIAN),
	SESOTHO(""),
	SETSUANA("tn"),
	SINDHI("sd"),
	SINHALA("si"),
	SLOVAK("sk"),
	SLOVENIAN("sl"),
	SOMALI("so"),
	SORBIAN("sb"),
	SPANISH("es"),
	SPANISH_ARGENTINA("es", "ar", SPANISH),
	SPANISH_BOLIVIA("es", "bo", SPANISH),
	SPANISH_CHILE("es", "cl", SPANISH),
	SPANISH_COLOMBIA("es", "co", SPANISH),
	SPANISH_COSTA_RICA("es", "cr", SPANISH),
	SPANISH_DOMINICAN_REPUBLIC("es", "do", SPANISH),
	SPANISH_ECUADOR("es", "ec", SPANISH),
	SPANISH_EL_SALVADOR("es", "sv", SPANISH),
	SPANISH_GUATEMALA("es", "gt", SPANISH),
	SPANISH_HONDURAS("es", "hn", SPANISH),
	SPANISH_MEXICO("es", "mx", SPANISH),
	SPANISH_NICARAGUA("es", "ni", SPANISH),
	SPANISH_PANAMA("es", "pa", SPANISH),
	SPANISH_PARAGUAY("es", "py", SPANISH),
	SPANISH_PERU("es", "pe", SPANISH),
	SPANISH_PUERTO_RICO("es", "pr", SPANISH),
	SPANISH_SPAIN("es", "es", SPANISH),
	SPANISH_SPAIN_TRADITIONAL("es", "es", SPANISH),
	SPANISH_UNITED_STATES("es", "us", SPANISH),
	SPANISH_URUGUAY("es", "uy", SPANISH),
	SPANISH_VENEZUELA("es", "ve", SPANISH),
	SWAHILI("sw"),
	SWEDISH("sv"),
	SWEDISH_FINLAND("sv", "fi", SWEDISH),
	SWEDISH_SWEDEN("sv", "se", SWEDISH),
	SYRIAC(""),
	TAJIK("tg"),
	TAMIL("ta"),
	TATAR("tt"),
	TELUGU("te"),
	THAI("th"),
	TIBETAN("bo"),
	TIBETAN_CHINA("bo", "cn", TIBETAN),
	TIBETAN_INDIA("bo", "in", TIBETAN),
	TSONGA("ts"),
	TURKISH("tr"),
	TURKMEN("tk"),
	UKRAINIAN("uk"),
	URDU("ur"),
	UZBEK("uz"),
	UZBEK_CYRILLIC("uz", "uz", UZBEK),
	UZBEK_LATIN("uz", "uz", UZBEK),
	VENDA(""),
	VIETNAMESE("vi"),
	WELSH("cy"), // United Kingdom
	XHOSA("xh"),
	YIDDISH("yi"),
	ZULU("zu");
	
	public final SimpleLocale generic;
	public final String languageCode;
	public final String countryCode;
	
	private static final SimpleLocale[] VALUES = values();
	public static SimpleLocale get(int ordinal) {
		return VALUES[ordinal];
	}
	
	private SimpleLocale(String languageCode) {
		generic = null;
		this.languageCode = languageCode;
		countryCode = null;
	}
	
	private SimpleLocale(String languageCode, String countryCode, SimpleLocale generic) {
		this.generic = generic;
		this.languageCode = languageCode;
		this.countryCode = countryCode;
	}
}

==> EntitySyncer-0.0.17-sources.jar: org/openzen/entitysyncer/SimpleLocale.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.openzen.entitysyncer;

import java.util.HashMap;
import java.util.Map;

/**
 *
 * @author Hoofdgebruiker
 */
public enum SimpleLocale {
	GENERIC(""),
	AFAR("af"),
	AFAR_DJIBOUTI("af", "dj", AFAR),
	AFAR_ERITREA("af", "er", AFAR),
	AFAR_ETHIOPIA("af", "et", AFAR),
	AFRIKAANS("af"),
	ALBANIAN("sq"),
	AMHARIC("am"), // Ethiopia
	ARAGONESE("an"), // Spain
	ARABIC("ar"),
	ARABIC_ALGERIA("ar", "dz", ARABIC),
	ARABIC_BAHRAIN("ar", "bh", ARABIC),
	ARABIC_EGYPT("ar", "eg", ARABIC),
	ARABIC_INDIA("ar", "in", ARABIC),
	ARABIC_IRAQ("ar", "iq", ARABIC),
	ARABIC_JORDAN("ar", "jo", ARABIC),
	ARABIC_KUWAIT("ar", "kw", ARABIC),
	ARABIC_LEBANON("ar", "lb", ARABIC),
	ARABIC_LIBYA("ar", "ly", ARABIC),
	ARABIC_MOROCCO("ar", "ma", ARABIC),
	ARABIC_OMAN("ar", "om", ARABIC),
	ARABIC_QATAR("ar", "qa", ARABIC),
	ARABIC_SAUDI_ARABIA("ar", "sa", ARABIC),
	ARABIC_SUDAN("ar", "sd", ARABIC),
	ARABIC_SYRIA("ar", "sy", ARABIC),
	ARABIC_TUNISIA("ar", "tn", ARABIC),
	ARABIC_EMIRATES("ar", "ae", ARABIC),
	ARABIC_YEMEN("ar", "ye", ARABIC),
	ARMENIAN("hy"),
	ASSAMESE("as"), // India
	ASTURIAN("ast"), // Spain
	AZERI("az"), // Azerbaijan
	AZERI_CYRILLIC("az", "az", AZERI),
	AZERI_LATIN("az", "az", AZERI),
	BASQUE("eu"),
	BELARUSIAN("be"),
	BENGALI("bn"),
	BENGALI_BANGLADESH("bn", "bn", BENGALI),
	BENGALI_INDIA("bn", "bn", BENGALI),
	BERBER("ber"),
	BERBER_ALGERIA("ber", "dz", BERBER),
	BERBER_MOROCCO("ber", "ma", BERBER),
	BHUTANI("dz"),
	BILIN("byn"), // Eritrea
	BOSNIAN("bs"),
	BRETON("br"),
	BULGARIAN("bg"),
	BURMESE("my"),
	CATALAN("ca"),
	CATALAN_ANDORRA("ca", "ad", CATALAN),
	CATALAN_SPAIN("ca", "es", CATALAN),
	CATALAN_FRANCE("ca", "fr", CATALAN),
	CATALAN_ITALIAN("ca", "it", CATALAN),
	CHINESE("zh"),
	CHINESE_CHINA("zh", "cn", CHINESE),
	CHINESE_HONGKONG("zh", "hk", CHINESE),
	CHINESE_MACAU("zh", "mo", CHINESE),
	CHINESE_SINGAPORE("zh", "sg", CHINESE),
	CHINESE_TAIWAN("zh", "tw", CHINESE),
	CRIMEAN_TARTAR("crh"), // Ukraine
	CROATIAN("hr"),
	CZECH("cs"),
	DANISH("da"),
	DIVEHI("dv"), // Maldives
	DUTCH("nl"),
	DUTCH_BELGIUM("nl", "be", DUTCH),
	DUTCH_NETHERLANDS("nl", "nl", DUTCH),
	EDO(""),
	ENGLISH("en"),
	ENGLISH_ANTIGUA_BARBUA("en", "ag", ENGLISH),
	ENGLISH_AUSTRALIA("en", "au", ENGLISH),
	ENGLISH_BELIZE("en", "bz", ENGLISH),
	ENGLISH_BOTSWANA("en", "bw", ENGLISH),
	ENGLISH_CANADA("en", "ca", ENGLISH),
	ENGLISH_CARIBBEAN("en", "cb", ENGLISH),
	ENGLISH_DENMARK("en", "dk", ENGLISH),
	ENGLISH_GREAT_BRITAIN("en", "gb", ENGLISH),
	ENGLISH_HONGKONG("en", "hk", ENGLISH),
	ENGLISH_INDIA("en", "in", ENGLISH),
	ENGLISH_IRELAND("en", "ie", ENGLISH),
	ENGLISH_JAMAICA("en", "jm", ENGLISH),
	ENGLISH_NEW_ZEALAND("en", "nz", ENGLISH),
	ENGLISH_NIGERIA("en", "ng", ENGLISH),
	ENGLISH_PHILLIPPINES("en", "ph", ENGLISH),
	ENGLISH_SINGAPORE("en", "sg", ENGLISH),
	ENGLISH_SOUTH_AFRICA("en", "za", ENGLISH),
	ENGLISH_TRINIDAD("en", "tt", ENGLISH),
	ENGLISH_UNITED_STATES("en", "us", ENGLISH),
	ENGLISH_ZIMBABWE("en", "", ENGLISH),
	ESPERANTO("eo"),
	ESTONIAN("et"),
	FYRO("mk"), // Macedonia
	FAROESE("fo"),
	FARSI("fa"), // Persian
	FINNISH("fi"),
	FRENCH("fr"),
	FRENCH_BELGIUM("fr", "be", FRENCH),
	FRENCH_CAMEROON("fr", "", FRENCH),
	FRENCH_CANADA("fr", "ca", FRENCH),
	FRENCH_CONGO("fr", "", FRENCH),
	FRENCH_COTE_DIVOIRE("fr", "", FRENCH),
	FRENCH_FRANCE("fr", "fr", FRENCH),
	FRENCH_LUXEMBURG("fr", "lu", FRENCH),
	FRENCH_MALI("fr", "", FRENCH),
	FRENCH_MONACO("fr", "", FRENCH),
	FRENCH_MOROCCO("fr", "", FRENCH),
	FRENCH_SENEGAL("fr", "", FRENCH),
	FRENCH_SWITZERLAND("fr", "ch", FRENCH),
	FRENCH_WEST_INDIES("fr", "", FRENCH),
	FRISIAN(""), // Netherlands
	GAELIC("gd"),
	GAELIC_IRELAND("gd", "ie", GAELIC),
	GAELIC_SCOTLAND("gd", "", GAELIC),
	GALICIAN("gl"),
	GEORGIAN("ka"),
	GERMAN("de"),
	GERMAN_AUSTRIA("de", "at", GERMAN),
	GERMAN_BELGIUM("de", "be", GERMAN),
	GERMAN_GERMANY("de", "de", GERMAN),
	GERMAN_LIECHTENSTEIN("de", "li", GERMAN),
	GERMAN_LUXEMBOURG("de", "lu", GERMAN),
	GERMAN_SWITZERLAND("de", "ch", GERMAN),
	GREEK("el"),
	GREEK_CYPRUS("el", "cy", GREEK),
	GREEK_GREECE("el", "gr", GREEK),
	GUARANI("gn"), // Paraguay
	GUJARITI("gu"),
	HEBREW("he"),
	HINDI("hi"),
	HUNGARIAN("hu"),
	ICELANDIC("is"),
	IGBO(""), // Nigeria
	INDONESIAN("id"),
	ITALIAN("it"),
	ITALIAN_ITALY("it", "it", ITALIAN),
	ITALIAN_SWITZERLAND("it", "ch", ITALIAN),
	JAPANESE("ja"),
	KANNADA("kn"),
	KASHMIRI("ks"),
	KASHUBIAN("csb"), // Poland
	KAZAKH("kk"),
	KHMER("km"),
	KONKANI(""),
	KOREAN("ko"),
	KYRGYZ(""),
	LAO("lo"),
	LATIN("la"),
	LATVIAN("lv"),
	LITHUANIAN("lt"),
	MALAY("ms"),
	MALAY_BRUNEI("ms", "bn", MALAY),
	MALAY_MALAYSIA("ms", "my", MALAY),
	MALAYALAM("ml"),
	MALTESE("mt"),
	MANIPURI(""),
	MAORI("mi"),
	MARATHI("mr"),
	MONGOLIAN("mn"),
	NEPALI("ne"),
	NORWEGIAN("no"),
	NORWEGIAN_BOKML("no", "nb", NORWEGIAN),
	NORWEGIAN_NYNORSK("no", "nn", NORWEGIAN),
	ORIYA("or"),
	POLISH("pl"),
	PORTUGUESE("pt"),
	PORTUGUESE_BRAZIL("pt", "br", PORTUGUESE),
	PORTUGUESE_PORTUGAL("pt", "pt", PORTUGUESE),
	PUNJABI("pa"),
	RAETO("rm"),
	ROMANIAN("ro"),
	ROMANIAN_MOLDOVA("ro", "mo", ROMANIAN),
	ROMANIAN_ROMANIA("ro", "ro", ROMANIAN),
	RUSSIAN("ru"),
	RUSSIAN_RUSSIA("ru", "ru", RUSSIAN),
	RUSSIAN_MOLDOVA("ru", "mo", RUSSIAN),
	SAMI_LAPPISH(""),
	SANSKRIT("sa"),
	SERBIAN("sr"),
	SERBIAN_CYRILLIC("sr", "sp", SERBIAN),
	SERBIAN_LATIN("sr", "sp", SERBIAN),
	SESOTHO(""),
	SETSUANA("tn"),
	SINDHI("sd"),
	SINHALA("si"),
	SLOVAK("sk"),
	SLOVENIAN("sl"),
	SOMALI("so"),
	SORBIAN("sb"),
	SPANISH("es"),
	SPANISH_ARGENTINA("es", "ar", SPANISH),
	SPANISH_BOLIVIA("es", "bo", SPANISH),
	SPANISH_CHILE("es", "cl", SPANISH),
	SPANISH_COLOMBIA("es", "co", SPANISH),
	SPANISH_COSTA_RICA("es", "cr", SPANISH),
	SPANISH_DOMINICAN_REPUBLIC("es", "do", SPANISH),
	SPANISH_ECUADOR("es", "ec", SPANISH),
	SPANISH_EL_SALVADOR("es", "sv", SPANISH),
	SPANISH_GUATEMALA("es", "gt", SPANISH),
	SPANISH_HONDURAS("es", "hn", SPANISH),
	SPANISH_MEXICO("es", "mx", SPANISH),
	SPANISH_NICARAGUA("es", "ni", SPANISH),
	SPANISH_PANAMA("es", "pa", SPANISH),
	SPANISH_PARAGUAY("es", "py", SPANISH),
	SPANISH_PERU("es", "pe", SPANISH),
	SPANISH_PUERTO_RICO("es", "pr", SPANISH),
	SPANISH_SPAIN("es", "es", SPANISH),
	SPANISH_SPAIN_TRADITIONAL("es", "es", SPANISH),
	SPANISH_UNITED_STATES("es", "us", SPANISH),
	SPANISH_URUGUAY("es", "uy", SPANISH),
	SPANISH_VENEZUELA("es", "ve", SPANISH),
	SWAHILI("sw"),
	SWEDISH("sv"),
	SWEDISH_FINLAND("sv", "fi", SWEDISH),
	SWEDISH_SWEDEN("sv", "se", SWEDISH),
	SYRIAC(""),
	TAJIK("tg"),
	TAMIL("ta"),
	TATAR("tt"),
	TELUGU("te"),
	THAI("th"),
	TIBETAN("bo"),
	TIBETAN_CHINA("bo", "cn", TIBETAN),
	TIBETAN_INDIA("bo", "in", TIBETAN),
	TSONGA("ts"),
	TURKISH("tr"),
	TURKMEN("tk"),
	UKRAINIAN("uk"),
	URDU("ur"),
	UZBEK("uz"),
	UZBEK_CYRILLIC("uz", "uz", UZBEK),
	UZBEK_LATIN("uz", "uz", UZBEK),
	VENDA(""),
	VIETNAMESE("vi"),
	WELSH("cy"), // United Kingdom
	XHOSA("xh"),
	YIDDISH("yi"),
	ZULU("zu");
	
	public final SimpleLocale generic;
	public final String languageCode;
	public final String countryCode;
	public final String fullCode;
	
	private static final SimpleLocale[] VALUES = values();
	public static SimpleLocale get(int ordinal) {
		return VALUES[ordinal];
	}
	
	private static final Map<String, SimpleLocale> VALUE_MAP = buildValueMap();
	public static SimpleLocale get(String language) {
		return VALUE_MAP.get(language.toLowerCase());
	}
	
	private SimpleLocale(String languageCode) {
		generic = null;
		this.languageCode = languageCode;
		countryCode = null;
		fullCode = languageCode;
	}
	
	private SimpleLocale(String languageCode, String countryCode, SimpleLocale generic) {
		this.generic = generic;
		this.languageCode = languageCode;
		this.countryCode = countryCode;
		fullCode = languageCode + "-" + countryCode;
	}
	
	private static Map<String, SimpleLocale> buildValueMap() {
		Map<String, SimpleLocale> result = new HashMap<>();
		for (SimpleLocale entry : VALUES) {
			result.put(entry.fullCode.toLowerCase(), entry);
		}
		return result;
	}
}
